"use strict";
// Copyright (c) CERBSim
// Distributed under the terms of the LGPLv2.1 License.
Object.defineProperty(exports, "__esModule", { value: true });
exports.WebguiDocuView = exports.WebguiView = exports.WebguiModel = void 0;
const base_1 = require("@jupyter-widgets/base");
const webgui_1 = require("webgui");
const version_1 = require("./version");
// Import the CSS
require("../css/widget.css");
class WebguiModel extends base_1.DOMWidgetModel {
    defaults() {
        return Object.assign(Object.assign({}, super.defaults()), { _model_name: WebguiModel.model_name, _model_module: WebguiModel.model_module, _model_module_version: WebguiModel.model_module_version, _view_name: WebguiModel.view_name, _view_module: WebguiModel.view_module, _view_module_version: WebguiModel.view_module_version, value: {} });
    }
}
WebguiModel.serializers = Object.assign({}, base_1.DOMWidgetModel.serializers);
WebguiModel.model_name = 'WebguiModel';
WebguiModel.model_module = version_1.MODULE_NAME;
WebguiModel.model_module_version = version_1.MODULE_VERSION;
WebguiModel.view_name = 'WebguiView'; // Set to null if no view
WebguiModel.view_module = version_1.MODULE_NAME; // Set to null if no view
WebguiModel.view_module_version = version_1.MODULE_VERSION;
exports.WebguiModel = WebguiModel;
class WebguiView extends base_1.DOMWidgetView {
    render() {
        this.el.classList.add('webgui-widget');
        const render_data = this.model.get('value');
        this.scene = new webgui_1.Scene(this);
        const container = document.createElement('div');
        container.setAttribute('style', 'height: 100%; width: 100%;');
        this.el.appendChild(container);
        setTimeout(() => {
            this.scene.init(container, render_data);
            this.scene.render();
        }, 0);
        this.model.on('change:value', this.value_changed, this);
    }
    value_changed() {
        const render_data = this.model.get('value');
        this.scene.updateRenderData(render_data);
    }
}
exports.WebguiView = WebguiView;
class WebguiDocuView extends base_1.DOMWidgetView {
    render() {
        // show preview image, a text message on hover
        // load real render data on click and start webgui
        const files = this.model.get('value');
        const image = files['preview'];
        this.container = $(`
      <div class="webgui_container" style="width:100%">
          <img src="${image}" class="image">
          <div class="webgui_overlay webgui_tooltip">
              <span class="webgui_tooltiptext"> Click to load interactive WebGUI </span>
          </div>
      </div>`);
        const div = document.createElement('div');
        this.container.click((el) => this.onClickImage(el));
        this.container.appendTo(div);
        this.el.appendChild(div);
        this.model.on('change:value', this.data_changed, this);
    }
    onClickImage(el) {
        document.body.style.cursor = 'wait';
        const files = this.model.get('value');
        $.get(files['render_data'], (render_data) => {
            document.body.style.cursor = '';
            const style = `width: ${this.el.clientWidth}px; height: ${this.el.clientHeight}px; display-style: none;`;
            this.container.remove();
            this.container = null;
            const pel = this.el.children[0];
            pel.innerHTML = '';
            pel.setAttribute('style', style);
            const scene = new webgui_1.Scene();
            scene.init(pel, render_data);
        });
    }
    data_changed() {
        const render_data = this.model.get('value');
        this.scene.updateRenderData(render_data);
    }
}
exports.WebguiDocuView = WebguiDocuView;
//# sourceMappingURL=widget.js.map